package info.bukova.isspst.mail;

import javax.mail.MessagingException;
import javax.mail.internet.MimeMessage;

import org.springframework.core.io.ByteArrayResource;
import org.springframework.core.io.InputStreamSource;
import org.springframework.mail.MailParseException;
import org.springframework.mail.javamail.JavaMailSender;
import org.springframework.mail.javamail.MimeMessageHelper;
import org.springframework.scheduling.annotation.Async;

public class MailerWithAttachement implements Mailer {
	
	private JavaMailSender sender;
	private String from;
	
	public MailerWithAttachement(JavaMailSender sender) {
		this.sender = sender;
	}
	
	@Override
	@Async
	public void send(MailMessage message) {
		MimeMessage mimeMessage = sender.createMimeMessage();

		try {
			MimeMessageHelper helper = new MimeMessageHelper(mimeMessage, true);
			
			if (message.getFrom() == null || message.getFrom().isEmpty()) {
				if (from == null || from.isEmpty()) {
					message.setFrom("tomcat@is.bukova.info");
				} else {
					message.setFrom(from);
				}
			}

			helper.setFrom(message.getFrom());
			helper.setTo(message.getTo());
			helper.setSubject(message.getSubject());
			helper.setText(message.getText(), message.isHtml());
			
			if (message.getAttachementData() != null) {
				InputStreamSource source = new  ByteArrayResource(message.getAttachementData());
				helper.addAttachment(message.getAttachementName(), source, message.getContentType());
			}
		} catch (MessagingException e) {
			throw new MailParseException(e);
		}
		sender.send(mimeMessage);
	}

	public void setFrom(String from) {
		this.from = from;
	}

}
