package info.bukova.isspst.validators;

import info.bukova.isspst.StringUtils;

import org.slf4j.Logger;
import org.zkoss.bind.Property;
import org.zkoss.bind.ValidationContext;
import org.zkoss.bind.validator.AbstractValidator;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.HtmlBasedComponent;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zk.ui.event.EventListener;
import org.zkoss.zul.Messagebox;

public abstract class BaseValidator extends AbstractValidator
{
	HtmlBasedComponent htmlComponent;
	
	protected Logger getLogger()
	{
		return null;
	}

	public void errorMsg(ValidationContext ctx, String msg, String componentIdFocused)
	{
		this.addInvalidMessage(ctx, msg);

		Logger logger = this.getLogger();

		if (logger != null)
		{
			logger.error(msg);
		}

		htmlComponent = null;
		
		if ((componentIdFocused != null) && (!componentIdFocused.isEmpty()))
		{
			Component component = ctx.getBindContext().getComponent().getFellowIfAny(componentIdFocused, true);

			if ((component != null) && (component instanceof HtmlBasedComponent))
			{
				htmlComponent = (HtmlBasedComponent) component;
			}
		}
		
		Messagebox.show(msg, StringUtils.localize("Error"), Messagebox.OK, Messagebox.ERROR, new EventListener<Event>()
		{
			public void onEvent(Event evt) throws InterruptedException
			{
				if (htmlComponent != null)
				{
					htmlComponent.setFocus(true);
				}
			}
		});
	}

	public void addErrorMsg(ValidationContext ctx, String msg)
	{
		this.errorMsg(ctx, msg, null);
	}
	
	protected boolean validateIsNotNull(ValidationContext ctx, String property, String errMessage, String componentId)
	{
		Property prop = ctx.getProperties(property)[0];
		Object value = prop.getValue();

		if (value == null)
		{
			this.errorMsg(ctx, StringUtils.localize(errMessage), componentId);
			return false;
		}
		
		return true;
	}
	
	protected boolean validateIsNotNullOrNotEmpty(ValidationContext ctx, String property, String errMessage, String componentId)
	{
		Property prop = ctx.getProperties(property)[0];
		Object value = prop.getValue();

		if (value == null)
		{
			this.errorMsg(ctx, StringUtils.localize(errMessage), componentId);
			return false;
		}
		
		if ((value instanceof String) && ((String)value).isEmpty())
		{
			this.errorMsg(ctx, StringUtils.localize(errMessage), componentId);
			return false;
		}
		
		return true;
	}
}
